from debyetools.tpropsgui.gui import gui
def gui():
    return gui
